@@ -16,24 +16,25 @@ from .exceptions import MangaNotFoundError
 click.option: Callable[..., Any] = functools.partial(click.option, show_default=True)  # type: ignore
 
 _log = logging.getLogger("tankobon")
-VERBOSITY = [
-    getattr(logging, level)
-    for level in ("CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG")
-]
 
 CONFIG = utils.CONFIG
 CONFIG_TYPES = [int, float, str]
 
 
-def prettyprint(dict_):
+def prettyprint(dict_, indent=0):
 
     for key, value in dict_.items():
 
         # +2 for the ': ' suffix
-        indent = len(key) + 2
+        indent_ = indent + len(key) + 2
 
         if isinstance(value, list):
-            value = f"\n{' ' * indent}".join(value)
+            value = f"\n{' ' * indent_}".join(value)
+
+        elif isinstance(value, dict):
+            if CONFIG["lang"] in value or "en" in value:
+                # a localised field of some kind.
+                value = value.get(CONFIG["lang"]) or value["en"]
 
         click.echo(f"{key}: {value}\n")
 
@@ -50,10 +51,7 @@ def _load(shorthash, cache):
 
 @click.group()
 @click.version_option(__version__)
-@click.option(
-    "-v", "--verbose", "verbosity", help="be more chatty", default=4, count=True
-)
-def cli(verbosity):
+def cli():
     """Manga browser/downloader.
 
     Once a manga has been added to tankobon using 'tankobon add <url>',
@@ -63,7 +61,7 @@ def cli(verbosity):
     """
     # set up logger
     coloredlogs.install(
-        level=VERBOSITY[verbosity - 1],
+        level=getattr(logging, CONFIG["log.level"]),
         fmt=" %(levelname)-8s :: %(message)s",
         logger=_log,
     )
