@@ -1,6 +1,6 @@
 # coding: utf8
 """
-# tankobon, version {version}
+# tankobon {version}
 
 Copyright (c) 2020-2021 Ong Yong Xin
 
@@ -24,6 +24,7 @@ from PySide6.QtCore import Qt, Signal, QSize
 from PySide6.QtGui import QAction, QIcon, QPixmap
 from PySide6.QtWidgets import (
     QApplication,
+    QCheckBox,
     QComboBox,
     QDialog,
     QDialogButtonBox,
@@ -235,6 +236,21 @@ class RateLimitSpinBox(QSpinBox):
         CONFIG["download.rate_limit"] = value
 
 
+class DataSaverCheckBox(QCheckBox):
+    def __init__(self):
+        super().__init__("Data saver (low-quality pages)")
+
+        state = Qt.Unchecked
+        if CONFIG["mangadex.data_saver"]:
+            state = Qt.Checked
+
+        self.setCheckState(state)
+        self.stateChanged.connect(self.onStateChanged)
+
+    def onStateChanged(self, state):
+        CONFIG["mangadex.data_saver"] = state == Qt.Checked
+
+
 class SettingsTab(QWidget):
     def __init__(self):
         super().__init__()
@@ -251,6 +267,7 @@ class Settings(QDialog):
         tabs = QTabWidget()
         tabs.addTab(self.general(), "General")
         tabs.addTab(self.downloads(), "Downloads")
+        tabs.addTab(self.sources(), "Sources")
         layout.addWidget(tabs)
 
         buttons = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
@@ -282,6 +299,19 @@ class Settings(QDialog):
 
         return tab
 
+    def sources(self):
+        tab = SettingsTab()
+
+        tab.layout.addWidget(QLabel("Mangadex"))
+
+        data_saver = DataSaverCheckBox()
+        data_saver.setToolTip(
+            "Download low-quality pages to save bandwidth and disk space."
+        )
+        tab.layout.addWidget(data_saver)
+
+        return tab
+
 
 class AboutBox(MessageBox):
     def __init__(self, *args):
@@ -404,6 +434,7 @@ class ItemInfoBox(QWidget):
 
         source = QLabel(f'<a href="{meta.url}">{meta.url}</b>')
         source.setWordWrap(True)
+        source.setOpenExternalLinks(True)
         layout.addWidget(source, 6, 1)
 
         langs_header = SubtitleLabel("Languages")
@@ -462,7 +493,10 @@ class PageViewToolBar(QToolBar):
     def __init__(self, total):
 
         super().__init__()
-        self.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Maximum)
+        self.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+        self.setStyleSheet("background-color: red")
+        self.setMovable(True)
+        self.setFloatable(True)
 
         self.pageno = 1
         self.total = total
@@ -516,26 +550,23 @@ class PageViewToolBar(QToolBar):
         self.setPage.emit(self.total)
 
 
-class PageView(QWidget):
+class PageView(QScrollArea):
     def __init__(self, parent, pages):
-        super().__init__(parent, Qt.Window)
-        self.layout = QVBoxLayout(self)
+        super().__init__(parent)
+        self.setSizePolicy(QSizePolicy.Ignored, QSizePolicy.Ignored)
+        self.setStyleSheet("background-color: #000000")
+        self.setWidgetResizable(True)
 
         self.pages = pages
 
         self.label = QLabel()
-        self.label.setSizePolicy(
-            QSizePolicy.MinimumExpanding, QSizePolicy.MinimumExpanding
-        )
         self.label.setScaledContents(True)
 
-        self.layout.addWidget(self.label, 0, Qt.AlignCenter)
+        self.setWidget(self.label)
 
         self.toolbar = PageViewToolBar(len(self.pages))
         self.toolbar.setPage.connect(self.onSetPage)
 
-        self.layout.addWidget(self.toolbar, 0, Qt.AlignCenter)
-
         self._height = self.label.height() + self.toolbar.height() / 2
 
         self.toolbar.start()
@@ -543,12 +574,6 @@ class PageView(QWidget):
     def onSetPage(self, pageno):
         pixmap = QPixmap(self.pages[pageno - 1])
 
-        height = self._height
-        width = (pixmap.width() / pixmap.height()) * height
-
-        print(width, height)
-
-        self.label.resize(width, height)
         self.label.setPixmap(pixmap)
 
 
@@ -865,7 +890,6 @@ class ChapterView(QTableWidget):
         self.buttons[chapter.id].setIcon(utils.icon("eye"))
 
         # pages = self.downloader.manifest[chapter.id][chapter.lang]
-
         # page_view = PageView(self, pages)
         # page_view.showMaximized()
 
@@ -884,6 +908,7 @@ class SummaryView(QWidget):
         self.layout.addWidget(chapters)
 
         desc = QLabel()
+        desc.setTextInteractionFlags(Qt.TextBrowserInteraction)
         desc.setWordWrap(True)
         desc.setTextFormat(Qt.RichText)
         desc.setOpenExternalLinks(True)
